## What is it?
Simple library to register any LOG comment in the code

## Instalation
pip install very_simple_logger

## Dependencies
logging

## License
MIT License

## Documentation
from very_simple_logger import Very_Simple_Logger<br/>
logger = Very_Simple_Logger().logger<br/>
logger.info(msg)<br/>